@@ -9,11 +9,13 @@
 {
   trade.offset = 0;
   quantmod <- getModelData(x);
-  if(class(quantmod) != "quantmod") stop("model must be of class quantmod");
-  if(!is.null(trade.dates) & length(trade.dates) < 2) stop("trade.dates must be of length 2");
+  if(!inherits(quantmod, "quantmod")) stop("model must be of class quantmod");
+  if(!is.null(trade.dates) && length(trade.dates) < 2) stop("trade.dates must be of length 2");
   model.data <- modelData(quantmod,trade.dates,exclude.training=exclude.training);
   fitted.zoo <- predictModel(quantmod@fitted.model,model.data,...)
-  if(class(fitted.zoo) != "zoo") {
+  if(inherits(fitted.zoo, "zoo", which = TRUE) != 1) {
+    # if(class(fitted.zoo) != "zoo") {
+    # /\ this is only needed if 'fitted.zoo' is not exactly a zoo object (i.e. not xts)
     fitted.zoo <- zoo(as.vector(fitted.zoo),index(model.data));
   }
   # trade Rule section
